@@ -5,7 +5,6 @@ a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
 #include "collect4output.h"
-#include "collect4output.moc"
 
 #include "scribusdoc.h"
 #include "scribuscore.h"
@@ -19,14 +18,15 @@ for which a new license (GPL+exception) is in place.
 #include "pageitem.h"
 #include "scraction.h"
 #include "scpattern.h"
+#include "util_file.h"
 
-#include <qmessagebox.h>
-#include <qstring.h>
-#include <qmap.h>
-#include <qdir.h>
+#include <QMessageBox>
+#include <QString>
+#include <QMap>
+#include <QDir>
 
 CollectForOutput::CollectForOutput(ScribusDoc* doc, bool withFontsA, bool withProfilesA, bool compressDocA)
-	: QObject(ScCore, 0),
+	: QObject(ScCore),
 	m_Doc(0)
 {
 	m_Doc=doc;
@@ -40,7 +40,7 @@ CollectForOutput::CollectForOutput(ScribusDoc* doc, bool withFontsA, bool withPr
 
 bool CollectForOutput::newDirDialog()
 {
-	QString curDir = QDir::currentDirPath();
+	QString curDir = QDir::currentPath();
 	if (ScCore->usingGUI())
 	{
 		QString wdir = ".";
@@ -64,7 +64,7 @@ QString CollectForOutput::collect()
 		return "";
 	ScCore->fileWatcher->forceScan();
 	ScCore->fileWatcher->stop();
-	dirs->set("collect", outputDirectory.left(outputDirectory.findRev("/",-2)));
+	dirs->set("collect", outputDirectory.left(outputDirectory.lastIndexOf("/",-2)));
 	ScCore->primaryMainWindow()->setStatusBarInfoText( tr("Collecting..."));
 
 	if (!collectItems())
@@ -173,10 +173,10 @@ bool CollectForOutput::collectItems()
 		}
 	}
 	QStringList patterns = m_Doc->getUsedPatterns();
-	for (uint c = 0; c < patterns.count(); ++c)
+	for (int c = 0; c < patterns.count(); ++c)
 	{
 		ScPattern pa = m_Doc->docPatterns[patterns[c]];
-		for (uint o = 0; o < pa.items.count(); o++)
+		for (int o = 0; o < pa.items.count(); o++)
 		{
 			processItem(pa.items.at(o));
 		}
@@ -189,20 +189,23 @@ void CollectForOutput::processItem(PageItem *ite)
 	if (ite->asImageFrame())
 	{
 		/* hack for subsequent c4o "./" -> "/doc/full/path" */
-		QString ofName(ite->Pfile);
-		QFileInfo itf = QFileInfo(ofName);
-		if (!itf.exists())
+		if (!ite->isInlineImage)
 		{
-			ofName = QDir::convertSeparators(PrefsManager::instance()->documentDir() + "/" + ofName);
-			itf.setFile(ofName);
-		}
+			QString ofName(ite->Pfile);
+			QFileInfo itf = QFileInfo(ofName);
+			if (!itf.exists())
+			{
+				ofName = QDir::convertSeparators(PrefsManager::instance()->documentDir() + "/" + ofName);
+				itf.setFile(ofName);
+			}
 		// end of hack
-		if (itf.exists())
-		{
-			QString oldFile = ofName;
-			ite->Pfile = collectFile(oldFile, itf.fileName());
-			ScCore->fileWatcher->removeFile(oldFile);
-			ScCore->fileWatcher->addFile(ite->Pfile);
+			if (itf.exists())
+			{
+				QString oldFile = ofName;
+				ite->Pfile = collectFile(oldFile, itf.fileName());
+				ScCore->fileWatcher->removeFile(oldFile);
+				ScCore->fileWatcher->addFile(ite->Pfile);
+			}
 		}
 	}
 	if (ite->asTextFrame())
@@ -212,13 +215,16 @@ void CollectForOutput::processItem(PageItem *ite)
 			QFileInfo itf;
 			if (!ite->Pfile.isEmpty())
 			{
-				itf = QFileInfo(ite->Pfile);
-				if (itf.exists())
+				if (!ite->isInlineImage)
 				{
-					QString oldFile = ite->Pfile;
-					ite->Pfile = collectFile(oldFile, itf.fileName());
-					ScCore->fileWatcher->removeFile(oldFile);
-					ScCore->fileWatcher->addFile(ite->Pfile);
+					itf = QFileInfo(ite->Pfile);
+					if (itf.exists())
+					{
+						QString oldFile = ite->Pfile;
+						ite->Pfile = collectFile(oldFile, itf.fileName());
+						ScCore->fileWatcher->removeFile(oldFile);
+						ScCore->fileWatcher->addFile(ite->Pfile);
+					}
 				}
 			}
 			if (!ite->Pfile2.isEmpty())
@@ -245,11 +251,76 @@ bool CollectForOutput::collectFonts()
 	for (it3 = m_Doc->UsedFonts.begin(); it3 != it3end; ++it3)
 	{
 		QFileInfo itf = QFileInfo(prefsManager->appPrefs.AvailFonts[it3.key()].fontFilePath());
-		copyFile(prefsManager->appPrefs.AvailFonts[it3.key()].fontFilePath(), outputDirectory + itf.fileName());
+		copyFileAtomic(prefsManager->appPrefs.AvailFonts[it3.key()].fontFilePath(), outputDirectory + itf.fileName());
+		if (prefsManager->appPrefs.AvailFonts[it3.key()].type() == ScFace::TYPE1)
+		{
+			QStringList metrics;
+			QString fontDir  = itf.absolutePath();
+			QString fontFile = itf.fileName();
+			metrics += findFontMetrics(fontDir, fontFile);
+			if ( metrics.size() <= 0 )
+			{
+				QDir dir;
+				if (dir.exists(fontDir + "/AFMs"))
+					metrics += findFontMetrics(fontDir + "/AFMs", fontFile);
+				if (dir.exists(fontDir + "/afm") && metrics.size() <= 0)
+					metrics += findFontMetrics(fontDir + "/afm", fontFile);
+				if (dir.exists(fontDir + "/Pfm") && metrics.size() <= 0)
+					metrics += findFontMetrics(fontDir + "/Pfm", fontFile);
+				if (dir.exists(fontDir + "/pfm") && metrics.size() <= 0)
+					metrics += findFontMetrics(fontDir + "/pfm", fontFile);
+			}
+			for (int a = 0; a < metrics.size(); a++)
+			{
+				QString origAFM = metrics[a];
+				QFileInfo fi(origAFM);
+				copyFileAtomic(origAFM, outputDirectory + fi.fileName());
+			}
+		}
 	}
 	return true;
 }
 
+QStringList CollectForOutput::findFontMetrics(const QString& baseDir, const QString& baseName) const
+{
+	QStringList metricsFiles;
+	QString     basePath = baseDir + "/" + baseName;
+	QString     afnm = basePath.left(basePath.length()-3);
+	// Look for afm files
+	QString afmName(afnm+"afm");
+	if(QFile::exists(afmName))
+		metricsFiles.append(afmName);
+	else
+	{
+		afmName = afnm+"Afm";
+		if(QFile::exists(afmName))
+			metricsFiles.append(afmName);
+		else
+		{
+			afmName = afnm+"AFM";
+			if(QFile::exists(afmName))
+				metricsFiles.append(afmName);
+		}
+	}
+	// Look for pfm files
+	QString pfmName(afnm+"pfm");
+	if(QFile::exists(pfmName))
+		metricsFiles.append(pfmName);
+	else
+	{
+		pfmName = afnm+"Pfm";
+		if(QFile::exists(pfmName))
+			metricsFiles.append(pfmName);
+		else
+		{
+			afmName = afnm+"PFM";
+			if(QFile::exists(pfmName))
+				metricsFiles.append(pfmName);
+		}
+	}
+	return metricsFiles;
+}
+
 bool CollectForOutput::collectProfiles()
 {
 	ProfilesL docProfiles;
@@ -257,9 +328,9 @@ bool CollectForOutput::collectProfiles()
 	ProfilesL::Iterator itend = docProfiles.end();
 	for (ProfilesL::Iterator it = docProfiles.begin(); it != itend; ++it)
 	{
-		QString profileName = it.key();
-		QString profilePath = it.data();
-		copyFile(profilePath, outputDirectory + QFileInfo(profilePath).fileName());
+		QString profileName(it.key());
+		QString profilePath(it.value());
+		copyFileAtomic(profilePath, outputDirectory + QFileInfo(profilePath).fileName());
 	}
 	return true;
 }
@@ -278,12 +349,12 @@ QString CollectForOutput::collectFile(QString oldFile, QString newFile)
 			break;
 		}
 		QFileInfo fi(newFile);
-		QString basename = fi.baseName().left(fi.baseName().findRev("_"));
-		newFile = QString("%1_%2.%3").arg(basename).arg(cnt).arg(fi.extension());
+		QString basename = fi.baseName().left(fi.baseName().lastIndexOf("_"));
+		newFile = QString("%1_%2.%3").arg(basename).arg(cnt).arg(fi.completeSuffix());
 		++cnt;
 	}
 	if (copy)
-		copyFile(oldFile, outputDirectory + newFile);
+		copyFileAtomic(oldFile, outputDirectory + newFile);
 	collectedFiles[newFile] = oldFile;
-	return newFile;
+	return outputDirectory + newFile;
 }
