@@ -25,7 +25,7 @@ There are 2 types of calender supported:
 But everything works with both orientations well of course too.
 
 AUTHOR:
-    Petr Vanek <petr@yarpen.cz>
+    Petr Vanek <petr@scribus.info>
 
 LICENSE:
 This program is free software; you can redistribute it and/or modify
@@ -68,22 +68,43 @@ except ImportError:
 
 
 localization = {
-'default' :
-    [['January', 'February', 'March', 'April', 'May',
-      'June', 'July', 'August', 'September', 'October',
-      'November', 'December'],
-     ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']],
-# alphabetically ordered
+'Catalan' :
+    [['Gener', 'Febrer', 'Març', 'Abril', 'Maig',
+      'Juny', 'Juliol', 'Agost', 'Setembre',
+      'Octubre', 'Novembre', 'Desembre'],
+     ['Dilluns', 'Dimarts', 'Dimecres', 'Dijous', 'Divendres', 'Dissabte', 'Diumenge']],
+'Catalan-short' :
+    [['Gener', 'Febrer', 'Març', 'Abril', 'Maig',
+      'Juny', 'Juliol', 'Agost', 'Setembre',
+      'Octubre', 'Novembre', 'Desembre'],
+     ['Dl', 'Dm', 'Dc', 'Dj', 'Dv', 'Ds', 'Dg']],
+# Catalan by "Cesc Morata" <atarom@gmail.com>
 'Czech' :
     [['Leden', 'Únor', 'Březen', 'Duben', 'Květen',
         'Červen', 'Červenec', 'Srpen', 'Září',
         'Říjen', 'Listopad', 'Prosinec'],
      ['Pondělí','Úterý','Středa','Čtvrtek','Pátek','Sobota', 'Neděle']],
+'Czech-short' :
+    [['Leden', 'Únor', 'Březen', 'Duben', 'Květen',
+        'Červen', 'Červenec', 'Srpen', 'Září',
+        'Říjen', 'Listopad', 'Prosinec'],
+     ['Po', 'Út', 'St', 'Čt', 'Pá', 'So', 'Ne']],
+'Dutch' :
+    [['Januari', 'Februari', 'Maart', 'April',
+      'Mei', 'Juni', 'Juli', 'Augustus', 'September',
+      'Oktober', 'November', 'December'],
+     ['Maandag','Dinsdag','Woensdag','Donderdag','Vrijdag','Zaterdag', 'Zondag']],
+# Dutch by "Christoph Schäfer" <christoph-schaefer@gmx.de>
 'English' :
     [['January', 'February', 'March', 'April',
       'May', 'June', 'July', 'August', 'September',
       'October', 'November', 'December'],
      ['Monday','Tuesday','Wednesday','Thursday','Friday','Saturday', 'Sunday']],
+'English-short' :
+    [['January', 'February', 'March', 'April', 'May',
+      'June', 'July', 'August', 'September', 'October',
+      'November', 'December'],
+     ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']],
 'Finnish' :
     [['Tammikuu', 'Helmikuu', 'Maaliskuu', 'Huhtikuu',
       'Toukokuu', 'Kesäkuu', 'Heinäkuu', 'Elokuu', 'Syyskuu',
@@ -101,9 +122,9 @@ localization = {
      ['Montag','Dienstag','Mittwoch','Donnerstag','Freitag','Samstag','Sonntag']],
 'Italian' :
     [['Gennaio', 'Febbraio', 'Marzo', 'Aprile',
-      u'Pu\xf2', 'Giugno', 'Luglio', 'Agosto', 'Settembre',
-      'Ottobre', 'Novembre', 'Dicembre'],
-     ['Lunedě','Martedě','Mercoledě','Giovedě',u'Venerd\xec','Sabato','Domenica']],
+       'Maggio', 'Giugno', 'Luglio', 'Agosto', 'Settembre',
+       'Ottobre', 'Novembre', 'Dicembre'],
+    [u'Luned\xec', u'Marted\xec', u'Mercoled\xec', u'Gioved\xec', u'Venerd\xec', 'Sabato', 'Domenica']],
 # Polish by "Łukasz [DeeJay1] Jernaś" <deejay1@nsj.srem.pl>
 'Polish' :
     [['Styczeń', 'Luty', 'Marzec', 'Kwiecień', 'Maj',
@@ -112,7 +133,7 @@ localization = {
      ['Poniedziałek', 'Wtorek', 'Środa', 'Czwartek', 'Piątek', 'Sobota', 'Niedziela']],
 'Portuguese' :
     [['Janeiro', 'Fevereiro', u'Mar\xe7o', 'Abril',
-      'Pode', 'Junho', 'Julho', 'Agosto', 'Setembro',
+      'Maio', 'Junho', 'Julho', 'Agosto', 'Setembro',
       'Outubro', 'Novembro', 'Dezembro'],
      ['Segunda-feira', u'Ter\xe7a-feira', 'Quarta-feira', 'Quinta-feira', 'Sexta-feira', u'S\xe1bado', 'Domingo']],
 'Russian' :
@@ -120,13 +141,21 @@ localization = {
       'Май', 'Июнь', 'Июль', 'Август', 'Сентябрь',
       'Октябрь', 'Ноябрь', 'Декабрь'],
      ['Понедельник','Вторник','Среда','Четверг','Пятница','Суббота', 'Воскресенье']],
-
+'Slovak' :
+    [['Január', 'Február', 'Marec', 'Apríl',
+      'Máj', 'Jún', 'Júl', 'August', 'September',
+      'Október', 'November', 'December'],
+      ['Pondelok','Utorok','Streda','Štvrtok','Piatok','Sobota', 'Nedeľa']],
+'Slovak-short' :
+    [['Január', 'Február', 'Marec', 'Apríl',
+      'Máj', 'Jún', 'Júl', 'August', 'September',
+      'Október', 'November', 'December'],
+      ['Po','Ut','St','Št','Pi','So', 'Ne']],
 'Spanish' :
-    [['Enero', 'Febrero', 'Marco', 'Abril', 'Mayo',
+    [['Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo',
       'Junio', 'Julio', 'Agosto', 'Septiembre',
       'Octubre', 'Noviembre', 'Diciembre'],
      ['Lunes', 'Martes', u'Mi\xe9rcoles', 'Jueves', 'Viernes', u'S\xe1bado', 'Domingo']],
-
 'Swedish' :
     [['Januari', 'Februari','Mars', 'April','Maj', 'Juni','Juli', 'Augusti','September', 'Oktober', 'November', 'December'],
      ['Måndag', 'Tisdag','Onsdag', 'Torsdag','Fredag', 'Lördag','Söndag']]
@@ -322,7 +351,7 @@ class TkCalendar(Frame):
     def __init__(self, master=None):
         """ Setup the dialog """
         # refernce to the localization dictionary
-        self.key = 'default'
+        self.key = 'English'
         Frame.__init__(self, master)
         self.grid()
         self.master.resizable(0, 0)
@@ -332,9 +361,20 @@ class TkCalendar(Frame):
         self.statusLabel = Label(self, textvariable=self.statusVar)
         self.statusVar.set('Select Options and Values')
         # langs
+        # change the height = to match number of langs.
         self.langLabel = Label(self, text='Select language:')
-        self.langListbox = Listbox(self, selectmode=SINGLE, height=10)
-        for i in localization.keys():
+
+        self.langFrame = Frame(self)
+        self.langFrame.pack()
+        self.langScrollbar = Scrollbar(self.langFrame)
+        self.langScrollbar.pack(fill=Y, side=RIGHT)
+        self.langListbox = Listbox(self.langFrame, selectmode=SINGLE, height=10, yscrollcommand=self.langScrollbar.set)
+        self.langListbox.pack(fill=X,side=LEFT)
+        self.langScrollbar.config(command=self.langListbox.yview)
+
+        keys = localization.keys()
+        keys.sort()
+        for i in keys:
             self.langListbox.insert(END, i)
         self.langButton = Button(self, text='Change language', command=self.languageChange)
         # calendar type
@@ -377,7 +417,7 @@ class TkCalendar(Frame):
         self.langLabel.grid(column=0, row=currRow, sticky=W)
         self.monthLabel.grid(column=3, row=currRow, sticky=W)
         currRow += 1
-        self.langListbox.grid(column=0, row=currRow, rowspan=6, sticky=N)
+        self.langFrame.grid(column=0, row=currRow, rowspan=6, sticky=N)
         self.typeLabel.grid(column=1, row=currRow, sticky=E)
         self.typeClRadio.grid(column=2, row=currRow, sticky=W)
         self.monthListbox.grid(column=3, row=currRow, rowspan=8)
@@ -405,7 +445,7 @@ class TkCalendar(Frame):
         # fill the values
         self.realLangChange()
 
-    def languageChange(self, lang='default'):
+    def languageChange(self, lang='English'):
         """ Called by Change button. Get language list value and
             call real re-filling. """
         ix = self.langListbox.curselection()
@@ -414,7 +454,7 @@ class TkCalendar(Frame):
             return
         self.realLangChange(lang=self.langListbox.get(ix[0]))
 
-    def realLangChange(self, lang='default'):
+    def realLangChange(self, lang='English'):
         """ Real widget setup. Ot takes values from localization dictionary.
         [0] = months, [1] Days """
         self.key = lang
